@@ -2,7 +2,7 @@
 
 void FileHeader::Reset(size_t SubDataSize)
 {
-  SubData.Alloc(SubDataSize);
+  SubData.resize(SubDataSize);
   BaseBlock::Reset();
   FileHash.Init(HASH_NONE);
   mtime.Reset();
@@ -37,6 +37,7 @@ void FileHeader::Reset(size_t SubDataSize)
 }
 
 
+/*
 FileHeader& FileHeader::operator = (FileHeader &hd)
 {
   SubData.Reset();
@@ -45,17 +46,10 @@ FileHeader& FileHeader::operator = (FileHeader &hd)
   SubData=hd.SubData;
   return *this;
 }
+*/
 
 
 void MainHeader::Reset()
 {
-  HighPosAV=0;
-  PosAV=0;
-  CommentInHeader=false;
-  PackComment=false;
-  Locator=false;
-  QOpenOffset=0;
-  QOpenMaxSize=0;
-  RROffset=0;
-  RRMaxSize=0;
+  *this={};
 }
