@@ -25,6 +25,13 @@
 #define   MMonthOct          L"October"
 #define   MMonthNov          L"November"
 #define   MMonthDec          L"December"
+#define   MWeekDayMon        L"Monday"
+#define   MWeekDayTue        L"Tuesday"
+#define   MWeekDayWed        L"Wednesday"
+#define   MWeekDayThu        L"Thursday"
+#define   MWeekDayFri        L"Friday"
+#define   MWeekDaySat        L"Saturday"
+#define   MWeekDaySun        L"Sunday"
 #define   MRARTitle1         L"\nUsage:     rar <command> -<switch 1> -<switch N> <archive> <files...>"
 #define   MUNRARTitle1       L"\nUsage:     unrar <command> -<switch 1> -<switch N> <archive> <files...>"
 #define   MRARTitle2         L"\n               <@listfiles...> <path_to_extract\\>"
@@ -254,8 +261,8 @@
 #define   MListLock          L"lock"
 #define   MListEnc           L"encrypted"
 #define   MListEncHead       L"encrypted headers"
-#define   MListTitleL        L" Attributes      Size     Date    Time   Name"
-#define   MListTitleV        L" Attributes      Size    Packed Ratio    Date    Time   Checksum  Name"
+#define   MListTitleL        L" Attributes       Size     Date    Time   Name"
+#define   MListTitleV        L" Attributes       Size     Packed Ratio    Date    Time   Checksum  Name"
 #define   MListName          L"Name"
 #define   MListType          L"Type"
 #define   MListFile          L"File"
