@@ -12,11 +12,11 @@ int main(int argc, char *argv[])
   ErrHandler.SetSignalHandlers(true);
 
 #ifdef SFX_MODULE
-  wchar ModuleName[NM];
+  std::wstring ModuleName;
 #ifdef _WIN_ALL
-  GetModuleFileName(NULL,ModuleName,ASIZE(ModuleName));
+  ModuleName=GetModuleFileStr();
 #else
-  CharToWide(argv[0],ModuleName,ASIZE(ModuleName));
+  CharToWide(argv[0],ModuleName);
 #endif
 #endif
 
@@ -35,9 +35,10 @@ int main(int argc, char *argv[])
   try 
   {
   
-    CommandData *Cmd=new CommandData;
+    // Use std::unique_ptr to free Cmd in case of exception.
+    std::unique_ptr<CommandData> Cmd(new CommandData);
 #ifdef SFX_MODULE
-    wcscpy(Cmd->Command,L"X");
+    Cmd->Command=L"X";
     char *Switch=argc>1 ? argv[1]:NULL;
     if (Switch!=NULL && Cmd->IsSwitch(Switch[0]))
     {
@@ -46,7 +47,10 @@ int main(int argc, char *argv[])
       {
         case 'T':
         case 'V':
-          Cmd->Command[0]=UpperCmd;
+          // Also copy 't' and 'a' modifiers for -v[t,a], if present.
+          Cmd->Command.clear();
+          for (char *c=Switch+1;*c!=0;c++)
+            Cmd->Command+=etoupper(*c);
           break;
         case '?':
           Cmd->OutHelp(RARX_SUCCESS);
@@ -68,6 +72,8 @@ int main(int argc, char *argv[])
 
 #if defined(_WIN_ALL) && !defined(SFX_MODULE)
     ShutdownOnClose=Cmd->Shutdown;
+    if (ShutdownOnClose!=POWERMODE_KEEP)
+      ShutdownCheckAnother(true);
 #endif
 
     uiInit(Cmd->Sound);
@@ -76,7 +82,6 @@ int main(int argc, char *argv[])
 
     Cmd->OutTitle();
     Cmd->ProcessCommand();
-    delete Cmd;
   }
   catch (RAR_EXIT ErrCode)
   {
@@ -93,10 +98,12 @@ int main(int argc, char *argv[])
   }
 
 #if defined(_WIN_ALL) && !defined(SFX_MODULE)
-  if (ShutdownOnClose!=POWERMODE_KEEP && ErrHandler.IsShutdownEnabled())
+  if (ShutdownOnClose!=POWERMODE_KEEP && ErrHandler.IsShutdownEnabled() &&
+      !ShutdownCheckAnother(false))
     Shutdown(ShutdownOnClose);
 #endif
   ErrHandler.MainExit=true;
+  CloseLogOptions();
   return ErrHandler.GetErrorCode();
 }
 #endif
