@@ -4,26 +4,29 @@
 class StringList
 {
   private:
-    Array<wchar> StringData;
+    std::vector<wchar> StringData;
     size_t CurPos;
 
-    uint StringsCount;
+    size_t StringsCount;
 
     size_t SaveCurPos[16],SavePosNumber;
   public:
     StringList();
     void Reset();
-    void AddStringA(const char *Str);
+//    void AddStringA(const char *Str);
     void AddString(const wchar *Str);
-    bool GetStringA(char *Str,size_t MaxLength);
+    void AddString(const std::wstring &Str);
+//    bool GetStringA(char *Str,size_t MaxLength);
     bool GetString(wchar *Str,size_t MaxLength);
+    bool GetString(std::wstring &Str);
     bool GetString(wchar *Str,size_t MaxLength,int StringNum);
+    bool GetString(std::wstring &Str,int StringNum);
     wchar* GetString();
     bool GetString(wchar **Str);
     void Rewind();
-    uint ItemsCount() {return StringsCount;};
-    size_t GetCharCount() {return StringData.Size();}
-    bool Search(const wchar *Str,bool CaseSensitive);
+    size_t ItemsCount() {return StringsCount;};
+    size_t GetCharCount() {return StringData.size();}
+    bool Search(const std::wstring &Str,bool CaseSensitive);
     void SavePosition();
     void RestorePosition();
 };
