@@ -511,8 +511,7 @@ void Unpack::UnpWriteArea(size_t StartPtr,size_t EndPtr)
 {
   if (EndPtr!=StartPtr)
     UnpSomeRead=true;
-  if (EndPtr<StartPtr)
-    UnpAllBuf=true;
+
 
   if (Fragmented)
   {
